# kanidm

A Python module for interacting with Kanidm.

Currently in very very very early beta, please [log an issue](https://github.com/kanidm/kanidm/issues/new/choose) for feature requests and bugs.

## Installation

```shell
python -m pip install kanidm
```

## Documentation

Documentation can be generated by [cloning the repository](https://github.com/kanidm/kanidm) and running `make docs/pykanidm/build`. The documentation will appear in `./pykanidm/site`. You'll need make and the [poetry](https://pypi.org/project/poetry/) package installed.


## Changelog

| Version | Date | Notes |
| ---     | ---  | ---   |
| 0.0.1   | 2022-08-16 | Initial release |
| 0.0.2   | 2022-08-16 | Updated license, including test code in package |
